@@ -1,22 +1,28 @@
 #-*- coding: utf-8 -*-
 from django import template
-from django.urls import reverse
+from django.urls import reverse, NoReverseMatch
 from django.conf import settings
-
 register = template.Library()
 
 @register.filter(name='get_child_sortable_list')
 def get_child_sortable_list(value):
     try:
         value_list = value.split('/')
-        obj_id = value_list[-3]
-        model_name = value_list[-4]
-        app_name = value_list[-5]
+        if len(value_list) == 5:
+            obj_id = 0
+            model_name = value_list[3]
+            app_name = value_list[2]
+        else:
+            obj_id = value_list[4]
+            model_name = value_list[3]
+            app_name = value_list[2]
+        return reverse('adminvisualsortable:sortable inlines', kwargs={'app': app_name, 'modelparentname': model_name, 'model_id': obj_id })
     except ValueError:
-        return None
+        return '/?error=ValueError'
     except IndexError:
-        return None
-    return reverse('adminvisualsortable:sortable inlines', kwargs={'app': app_name, 'modelparentname': model_name, 'model_id': obj_id })
+        return '/?error=InextError'
+    except NoReverseMatch:
+        return '/?error=NoReverseMatch'
 
 
 @register.filter(name='get_parent_visualorder_url')
@@ -36,4 +42,4 @@ def get_parent_admin_url_list(value):
     model = value
     modelname = model['name'].lower()
     app = model['app_name']
-    return '/admin/{}/{}/'.format(app, modelname)
+    return '{}/admin/{}/{}/'.format(settings.HOST, app, modelname)
