@@ -42,7 +42,10 @@ def sortable_inlines_detail(request, app, modelparentname, model_id, modelname,
     preview_field = False
     TargetModelParent = apps.get_model('{}.{}'.format(app, modelparentname))
     TargetModel = apps.get_model('{}.{}'.format(app, modelname))
-    parent_instance = TargetModelParent.objects.get(id=model_id)
+    if model_id == 0: # Could Be A SingleTone Admin Model
+        parent_instance = TargetModelParent.objects.first()
+    else:
+        parent_instance = TargetModelParent.objects.get(id=model_id)
     ordering_field = TargetModel._meta.ordering[0]
     if fkfield is None:
         # se non indicato proviamo a pescarlo in autonomia
@@ -65,18 +68,27 @@ def sortable_inlines_detail(request, app, modelparentname, model_id, modelname,
             if getattr(field, 'attr_class', None) == django.db.models.fields.files.ImageFieldFile:
                 preview_field = field.name
                 break
+    idx_list = []
+    warning_dups = False
     for q in queryset:
         if preview_field:
             res.append({'ord': getattr(q, ordering_field), 'obj': q, 'img': getattr(q, preview_field)  })
         else:
             res.append({'ord': getattr(q, ordering_field), 'obj': q, 'img': 'NOIMAGE'  })
-
+        if getattr(q, ordering_field) in idx_list:
+            warning_dups = True
+            break
+        else:
+            idx_list.append(getattr(q, ordering_field))
+    if warning_dups:
+        from django.core.management import call_command
+        call_command('reorder', '{}.{}'.format(app.lower(), modelname.lower()))
+        return HttpResponseRedirect(request.path)
     parent_is_sortable = False
     for k,v in admin.site._registry.items():
         if k.__name__.lower() == modelparentname:
             if hasattr(v, 'is_adminvisualsortable') and v.is_adminvisualsortable:
                 parent_is_sortable = True
-
     inline_list = []
     for k,v in admin.site._registry.items():
         if v.inlines:
@@ -101,8 +113,6 @@ def sortable_inlines_detail(request, app, modelparentname, model_id, modelname,
         'preview_field': preview_field,
         'parent_multi_inlines': parent_multi_inlines,
         'parent_pivot_url': parent_pivot_url,
-        'parent_sort_url': reverse('adminvisualsortable:sort models',
-                                    kwargs={'app': app, 'modelname': modelparentname, }),
         'parent_is_sortable': parent_is_sortable,
         'site_header': admin.site.site_header
     }
@@ -176,7 +186,10 @@ def sortable_inlines(request, app, modelparentname, model_id):
     ''' If one Inline sortable show sortable layout '''
     ''' If more then one show or should show list of possible inlines to sort'''
     TargetModelParent = apps.get_model('{}.{}'.format(app, modelparentname))
-    parent_instance = TargetModelParent.objects.get(id=model_id)
+    if model_id == 0: # SingleTone Admin
+        parent_instance = TargetModelParent.objects.first()
+    else:
+        parent_instance = TargetModelParent.objects.get(id=model_id)
     inline_list = []
     for k,v in admin.site._registry.items():
         if v.inlines:
@@ -191,7 +204,6 @@ def sortable_inlines(request, app, modelparentname, model_id):
             'modelparentname': modelparentname,
             'model_id': model_id,
             'modelname': inline_list[0].__name__.lower(),
-            'parent_instance': parent_instance,
         }))
     else:
         # Verificare se il padre è ordinabile
